@@ -7,14 +7,14 @@ use strict;
 
 package XML::Compile::Schema::BuiltInFacets;
 use vars '$VERSION';
-$VERSION = '0.73';
+$VERSION = '0.74';
 use base 'Exporter';
 
 
 our @EXPORT = qw/builtin_facet/;
 
 use Log::Report     'xml-compile', syntax => 'SHORT';
-use Math::BigInt    try => 'GMP';
+use Math::BigInt;
 use Math::BigFloat;
 
 use constant DBL_MAX_DIG => 15;
